#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time


def run():
    print 'Para las aventuras que puedan acontecerte:'
    time.sleep(5)
    print 'No guardes todo en el mismo Bucket...'
    time.sleep(5)
    print 'Recuerda que Buchannon siempre esta vigilando...'
    time.sleep(5)
    print 'Y MarkFelt tambien...'
    time.sleep(5)
    print 'Cornelius es un nombre feo desde que David mato a Goliath...'
    time.sleep(5)
    print 'pero los nombres feos tienen gancho entre desarrolladores XD'
    time.sleep(5)
    print 'Las cosas claras...'
    time.sleep(3)
    print 'el chocolate espeso...'
    time.sleep(3)
    print 'y el ColaCao.. EN CASA!'
    time.sleep(5)
    print 'Y sobre todo...'
    time.sleep(5)
    print 'mantente alejado de Ms Neumar.'
    time.sleep(5)
    print 'Y para despedir, algo mas emotivo:'
    time.sleep(5)
    print 'Cuando no sea tu mejor dia...'
    time.sleep(5)
    print 'pon a cocer arroz durante dos horas...'
    time.sleep(5)
    print 'veras como se te pasa.'
    time.sleep(3)


run()
