#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time


def run():

        print("\033[0;30;47m ###### Ahora has decidido cambiar de aires...")
        time.sleep(2)
        print("\033[0;31;47m ###### Porque levantar una empresa de cero ya lo has tachado...")
        time.sleep(2)
        print("\033[0;33;47m ###### Y cuando la gente te pregunte Why?...ya sabes que contestar... ;) \n")
        time.sleep(3)
        print("\033[0;31;47m ###### Gracias por todo lo que nos has ensenado...y no solo de programacion!")
        time.sleep(2)
        print("\033[0;33;47m ###### Pero no te vayas a olvidar de nosotros...")
        time.sleep(2)
        print("\033[0;31;47m ###### Que la vida da muchas vueltas....amigo.")
        time.sleep(3)
        print("\033[0m      Has visto? Ya soy un crack con python!!!!\n")
        time.sleep(2)
        print("Created by Gerard")

run()
